--
-- ============LICENSE_START=======================================================
-- Copyright (C) 2024 Ericsson
-- Modifications Copyright (C) 2024 OpenInfra Foundation Europe
-- ================================================================================
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
--
--       http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.
--
-- SPDX-License-Identifier: Apache-2.0
-- ============LICENSE_END=========================================================
--

CREATE EXTENSION IF NOT EXISTS postgis;
CREATE EXTENSION IF NOT EXISTS postgis_topology;

GRANT USAGE ON SCHEMA topology to :pguser;
GRANT SELECT ON ALL SEQUENCES IN SCHEMA topology TO :pguser;
GRANT SELECT ON ALL TABLES IN SCHEMA topology TO :pguser;

CREATE SCHEMA IF NOT EXISTS ties_data;
ALTER SCHEMA ties_data OWNER TO :pguser;
SET default_tablespace = '';
SET default_table_access_method = heap;

SET ROLE :'pguser';

-- Function to create CONSTRAINT only if it does not exists
CREATE OR REPLACE FUNCTION ties_data.create_constraint_if_not_exists (
	t_name TEXT, c_name TEXT, constraint_sql TEXT
)
RETURNS void AS
$$
BEGIN
	IF NOT EXISTS (SELECT constraint_name FROM information_schema.table_constraints WHERE table_name = t_name AND constraint_name = c_name) THEN
		EXECUTE constraint_sql;
	END IF;
END;
$$ language 'plpgsql';

CREATE TABLE IF NOT EXISTS ties_data."003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"name"			TEXT,
	"REL_FK_C2F5EC33C0760F653CE7263A49C0B697FCA2D542"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_26958E3A529C4C8B68A29FDA906F8CD290F66078"			VARCHAR(511),
	"REL_ID_B7945BFD83380F3E12CF99F2B0F838F364027F92"			VARCHAR(511),
	"REL_CD_B7945BFD83380F3E12CF99F2B0F838F364027F92"			jsonb
);

ALTER TABLE ONLY ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" ALTER COLUMN "REL_CD_B7945BFD83380F3E12CF99F2B0F838F364027F92" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"name"			TEXT,
	"REL_FK_AB87B417CCD05C332DDD0C60F0C6AB41D38B05E5"			VARCHAR(511),
	"REL_ID_FC2F6A5A12917357B548C83F4B0C1AD58FA61413"			VARCHAR(511),
	"REL_CD_CEAD4CCE5250E7D3C64801C8FDDC21F1D87BEC0C"			jsonb,
	"REL_FK_8C98B70070BBD11F90F192DDA3ECF6302390E956"			VARCHAR(511),
	"REL_ID_AFBF10D23507AD3B6408947D2A9AF8465BA7B08C"			VARCHAR(511),
	"REL_CD_F7E43E0D0F76D6EFED9AB684B84A69E177F591D2"			jsonb
);

ALTER TABLE ONLY ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ALTER COLUMN "REL_CD_CEAD4CCE5250E7D3C64801C8FDDC21F1D87BEC0C" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ALTER COLUMN "REL_CD_F7E43E0D0F76D6EFED9AB684B84A69E177F591D2" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"020335B0F627C169E24167748C38FE756FB34AE2"			BIGINT,
	"nRTAC"			BIGINT,
	"nRPCI"			BIGINT,
	"cmId"			jsonb,
	"fdn"			TEXT,
	"nCI"			BIGINT,
	"REL_FK_609963BFEE15FF824280FBE201313C3CDACDDDCE"			VARCHAR(511),
	"REL_ID_040FC8B06B420BA5708AF4798102D1E65FB4DC61"			VARCHAR(511),
	"REL_CD_040FC8B06B420BA5708AF4798102D1E65FB4DC61"			jsonb
);

ALTER TABLE ONLY ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" ALTER COLUMN "REL_CD_040FC8B06B420BA5708AF4798102D1E65FB4DC61" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."78682DB1FFA2533BA45F8E4FAA5596E1A98479FC" (
	"id"			VARCHAR(511),
	"name"			TEXT,
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."78682DB1FFA2533BA45F8E4FAA5596E1A98479FC" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"gNBDUId"			BIGINT,
	"cmId"			jsonb,
	"3786A6CA64C9422F9E7FC35B7B039F345BBDDA65"			TEXT,
	"gNBIdLength"			BIGINT,
	"dUpLMNId"			jsonb,
	"gNBId"			BIGINT,
	"REL_FK_48B14FA5B787C6398AD1DE5EE670AD0D2A2CB36F"			VARCHAR(511),
	"REL_ID_BDE0B6C74D14AC109D29A08D80E92D4D0DCAEB0B"			VARCHAR(511),
	"REL_CD_45E8E8693B1B8928376EAA8995D08AA7B1E483BD"			jsonb
);

ALTER TABLE ONLY ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" ALTER COLUMN "REL_CD_45E8E8693B1B8928376EAA8995D08AA7B1E483BD" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."AC201B3A42917A9A983A1E3683B67C38C50630FC" (
	"id"			VARCHAR(511),
	"aSide_B0FD0521695A211BFF76F413A31F28CBA32E57ED"			VARCHAR(511),
	"bSide_84EF1134719BB6FCF33A94FF770311FC722BCF41"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."AC201B3A42917A9A983A1E3683B67C38C50630FC" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE" (
	"id"			VARCHAR(511),
	"aSide_AntennaCapability"			VARCHAR(511),
	"bSide_AntennaModule"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."AntennaCapability" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"eUtranFqBands"			jsonb,
	"fdn"			TEXT,
	"geranFqBands"			jsonb,
	"nRFqBands"			jsonb,
	"cmId"			jsonb,
	"REL_FK_used-by-lteSectorCarrier"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."AntennaCapability" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."AntennaModule" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"totalTilt"			BIGINT,
	"mechanicalAntennaBearing"			BIGINT,
	"fdn"			TEXT,
	"antennaModelNumber"			TEXT,
	"mechanicalAntennaTilt"			BIGINT,
	"positionWithinSector"			TEXT,
	"cmId"			jsonb,
	"electricalAntennaTilt"			BIGINT,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_ANTENNAMODULE"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_ANTENNAMODULE"			jsonb,
	"REL_FK_installed-at-site"			VARCHAR(511),
	"REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE"			VARCHAR(511),
	"REL_CD_sourceIds_ANTENNAMODULE_INSTALLED_AT_SITE"			jsonb
);

ALTER TABLE ONLY ties_data."AntennaModule" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."AntennaModule" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_ANTENNAMODULE" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."AntennaModule" ALTER COLUMN "REL_CD_sourceIds_ANTENNAMODULE_INSTALLED_AT_SITE" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."ANTENNAMODULE_REALISED_BY_ANTENNAMODULE" (
	"id"			VARCHAR(511),
	"aSide_AntennaModule"			VARCHAR(511),
	"bSide_AntennaModule"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."ANTENNAMODULE_REALISED_BY_ANTENNAMODULE" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6" (
	"id"			VARCHAR(511),
	"aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C"			VARCHAR(511),
	"bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."C35AE10CFF62DEDC5E3FC3C40E47373B10800818" (
	"id"			VARCHAR(511),
	"aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C"			VARCHAR(511),
	"bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."C35AE10CFF62DEDC5E3FC3C40E47373B10800818" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."CloudNativeApplication" (
	"id"			VARCHAR(511),
	"name"			TEXT,
	"CD_sourceIds"			jsonb,
	"REL_FK_realised-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_REALISED_BY_CLOUDNATIVEAPPLICATION"			VARCHAR(511),
	"REL_CD_8F561B5FB3CF928F2C4046CE1A7C37A8FE06B9A7"			jsonb,
	"REL_FK_comprised-by-cloudNativeSystem"			VARCHAR(511),
	"REL_ID_CLOUDNATIVESYSTEM_COMPRISES_CLOUDNATIVEAPPLICATION"			VARCHAR(511),
	"REL_CD_39262797D0119611B8459ECF46754A074711E485"			jsonb,
	"REL_FK_deployed-on-namespace"			VARCHAR(511),
	"REL_ID_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			VARCHAR(511),
	"REL_CD_sourceIds_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			jsonb
);

ALTER TABLE ONLY ties_data."CloudNativeApplication" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."CloudNativeApplication" ALTER COLUMN "REL_CD_8F561B5FB3CF928F2C4046CE1A7C37A8FE06B9A7" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."CloudNativeApplication" ALTER COLUMN "REL_CD_39262797D0119611B8459ECF46754A074711E485" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."CloudNativeApplication" ALTER COLUMN "REL_CD_sourceIds_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."CloudNativeSystem" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"name"			TEXT,
	"REL_FK_deployed-managedElement"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."CloudNativeSystem" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."CloudSite" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"name"			TEXT,
	"geo-location"			geography
);

ALTER TABLE ONLY ties_data."CloudSite" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."ENodeBFunction" (
	"id"			VARCHAR(511),
	"fdn"			TEXT,
	"eNBId"			BIGINT,
	"cmId"			jsonb,
	"eNodeBPlmnId"			jsonb,
	"CD_sourceIds"			jsonb,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			jsonb,
	"REL_FK_realised-by-physicalNetworkAppliance"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_REALISED_BY_PHYSICALNETWORKAPPLIANCE"			VARCHAR(511),
	"REL_CD_556274C475BA56EE4DEFB691F9037C869223A124"			jsonb
);

ALTER TABLE ONLY ties_data."ENodeBFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."ENodeBFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."ENodeBFunction" ALTER COLUMN "REL_CD_556274C475BA56EE4DEFB691F9037C869223A124" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."EUtranCell" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"earfcn"			BIGINT,
	"earfcndl"			BIGINT,
	"duplexType"			TEXT,
	"fdn"			TEXT,
	"tac"			BIGINT,
	"earfcnul"			BIGINT,
	"cmId"			jsonb,
	"cellId"			BIGINT,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_EUTRANCELL"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_EUTRANCELL"			jsonb,
	"REL_FK_provided-by-enodebFunction"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			VARCHAR(511),
	"REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			jsonb
);

ALTER TABLE ONLY ties_data."EUtranCell" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."EUtranCell" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_EUTRANCELL" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."EUtranCell" ALTER COLUMN "REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_EUTRANCELL" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" (
	"id"			VARCHAR(511),
	"aSide_GNBCUCPFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"         jsonb
);

ALTER TABLE ONLY ties_data."GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."GNBCUCPFunction" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"fdn"			TEXT,
	"pLMNId"			jsonb,
	"gNBCUName"			TEXT,
	"gNBId"			BIGINT,
	"cmId"			jsonb,
	"gNBIdLength"			BIGINT,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			jsonb
);

ALTER TABLE ONLY ties_data."GNBCUCPFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."GNBCUCPFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" (
	"id"			VARCHAR(511),
	"aSide_GNBCUUPFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"     jsonb
);

ALTER TABLE ONLY ties_data."GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."GNBCUUPFunction" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"gNBId"			BIGINT,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"gNBIdLength"			BIGINT,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			jsonb
);

ALTER TABLE ONLY ties_data."GNBCUUPFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."GNBCUUPFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" (
	"id"			VARCHAR(511),
	"aSide_GNBDUFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"     jsonb
);

ALTER TABLE ONLY ties_data."GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."GNBDUFunction" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"fdn"			TEXT,
	"gNBId"			BIGINT,
	"dUpLMNId"			jsonb,
	"gNBDUId"			BIGINT,
	"cmId"			jsonb,
	"gNBIdLength"			BIGINT,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"       jsonb
);

ALTER TABLE ONLY ties_data."GNBDUFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."GNBDUFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."LTESectorCarrier" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"sectorCarrierType"			TEXT,
	"essScLocalId"			BIGINT,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_provided-by-enodebFunction"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			jsonb,
	"REL_FK_used-antennaCapability"			VARCHAR(511),
	"REL_ID_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			VARCHAR(511),
	"REL_CD_sourceIds_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_FK_used-by-euTranCell"			VARCHAR(511),
	"REL_ID_EUTRANCELL_USES_LTESECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_EUTRANCELL_USES_LTESECTORCARRIER"			jsonb
);

ALTER TABLE ONLY ties_data."LTESectorCarrier" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."LTESectorCarrier" ALTER COLUMN "REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."LTESectorCarrier" ALTER COLUMN "REL_CD_sourceIds_LTESECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."LTESectorCarrier" ALTER COLUMN "REL_CD_sourceIds_EUTRANCELL_USES_LTESECTORCARRIER" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."ManagedElement" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_deployed-as-cloudNativeSystem"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			jsonb
);

ALTER TABLE ONLY ties_data."ManagedElement" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."ManagedElement" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."NRCellCU" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"nCI"			BIGINT,
	"plmnId"			jsonb,
	"fdn"			TEXT,
	"nRTAC"			BIGINT,
	"cellLocalId"			BIGINT,
	"cmId"			jsonb,
	"REL_FK_provided-by-gnbcucpFunction"			VARCHAR(511),
	"REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			VARCHAR(511),
	"REL_CD_sourceIds_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			jsonb
);

ALTER TABLE ONLY ties_data."NRCellCU" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRCellCU" ALTER COLUMN "REL_CD_sourceIds_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."NRCellDU" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"nRTAC"			BIGINT,
	"fdn"			TEXT,
	"nRPCI"			BIGINT,
	"nCI"			BIGINT,
	"cellLocalId"			BIGINT,
	"cmId"			jsonb,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_NRCELLDU"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_NRCELLDU"			jsonb,
	"REL_FK_provided-by-gnbduFunction"			VARCHAR(511),
	"REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU"			VARCHAR(511),
	"REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRCELLDU"			jsonb
);

ALTER TABLE ONLY ties_data."NRCellDU" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRCellDU" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_NRCELLDU" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRCellDU" ALTER COLUMN "REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRCELLDU" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."NRSectorCarrier" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"frequencyDL"			BIGINT,
	"arfcnDL"			BIGINT,
	"fdn"			TEXT,
	"essScLocalId"			BIGINT,
	"frequencyUL"			BIGINT,
	"cmId"			jsonb,
	"arfcnUL"			BIGINT,
	"REL_FK_used-by-nrCellDu"			VARCHAR(511),
	"REL_ID_NRCELLDU_USES_NRSECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_NRCELLDU_USES_NRSECTORCARRIER"			jsonb,
	"REL_FK_provided-by-gnbduFunction"			VARCHAR(511),
	"REL_ID_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			jsonb,
	"REL_FK_used-antennaCapability"			VARCHAR(511),
	"REL_ID_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			VARCHAR(511),
	"REL_CD_sourceIds_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb
);

ALTER TABLE ONLY ties_data."NRSectorCarrier" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRSectorCarrier" ALTER COLUMN "REL_CD_sourceIds_NRCELLDU_USES_NRSECTORCARRIER" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRSectorCarrier" ALTER COLUMN "REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NRSectorCarrier" ALTER COLUMN "REL_CD_sourceIds_NRSECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."Namespace" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"name"			TEXT,
	"REL_FK_deployed-on-nodeCluster"			VARCHAR(511),
	"REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			VARCHAR(511),
	"REL_CD_sourceIds_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			jsonb
);

ALTER TABLE ONLY ties_data."Namespace" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."Namespace" ALTER COLUMN "REL_CD_sourceIds_NAMESPACE_DEPLOYED_ON_NODECLUSTER" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."NodeCluster" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"name"			TEXT,
	"REL_FK_located-at-cloudSite"			VARCHAR(511),
	"REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE"			VARCHAR(511),
	"REL_CD_sourceIds_NODECLUSTER_LOCATED_AT_CLOUDSITE"			jsonb
);

ALTER TABLE ONLY ties_data."NodeCluster" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."NodeCluster" ALTER COLUMN "REL_CD_sourceIds_NODECLUSTER_LOCATED_AT_CLOUDSITE" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."PhysicalNetworkAppliance" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"geo-location"			geography,
	"name"			TEXT,
	"cmId"			jsonb,
	"type"			TEXT,
	"REL_FK_installed-at-site"			VARCHAR(511),
	"REL_ID_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			VARCHAR(511),
	"REL_CD_sourceIds_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			jsonb
);

ALTER TABLE ONLY ties_data."PhysicalNetworkAppliance" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."PhysicalNetworkAppliance" ALTER COLUMN "REL_CD_sourceIds_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE" SET DEFAULT '[]';


CREATE TABLE IF NOT EXISTS ties_data."Sector" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"azimuth"			DECIMAL,
	"geo-location"			geography,
	"sectorId"			BIGINT
);

ALTER TABLE ONLY ties_data."Sector" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."Site" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"name"			TEXT,
	"geo-location"			geography,
	"cmId"			jsonb
);

ALTER TABLE ONLY ties_data."Site" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."TESTENTITYA_GROUPS_TESTENTITYB" (
	"id"			VARCHAR(511),
	"aSide_TestEntityA"			VARCHAR(511),
	"bSide_TestEntityB"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."TESTENTITYA_GROUPS_TESTENTITYB" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."TESTENTITYA_PROVIDES_TESTENTITYB" (
	"id"			VARCHAR(511),
	"aSide_TestEntityA"			VARCHAR(511),
	"bSide_TestEntityB"			VARCHAR(511),
	"CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."TESTENTITYA_PROVIDES_TESTENTITYB" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."TestEntityA" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"attribute1"			TEXT
);

ALTER TABLE ONLY ties_data."TestEntityA" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."TestEntityB" (
	"id"			VARCHAR(511),
    "CD_sourceIds"			jsonb,
	"attribute1"			TEXT,
	"REL_FK_used-by-testEntityA"			VARCHAR(511),
	"REL_ID_TESTENTITYA_USES_TESTENTITYB"			VARCHAR(511),
	"REL_CD_sourceIds_TESTENTITYA_USES_TESTENTITYB"			jsonb
);

ALTER TABLE ONLY ties_data."TestEntityB" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

ALTER TABLE ONLY ties_data."TestEntityB" ALTER COLUMN "REL_CD_sourceIds_TESTENTITYA_USES_TESTENTITYB" SET DEFAULT '[]';

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_GROUPS_TESTENTITYB',
 'PK_TESTENTITYA_GROUPS_TESTENTITYB_id',
 'ALTER TABLE ties_data."TESTENTITYA_GROUPS_TESTENTITYB" ADD CONSTRAINT "PK_TESTENTITYA_GROUPS_TESTENTITYB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_PROVIDES_TESTENTITYB',
 'PK_TESTENTITYA_PROVIDES_TESTENTITYB_id',
 'ALTER TABLE ties_data."TESTENTITYA_PROVIDES_TESTENTITYB" ADD CONSTRAINT "PK_TESTENTITYA_PROVIDES_TESTENTITYB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TestEntityA',
 'PK_TestEntityA_id',
 'ALTER TABLE ties_data."TestEntityA" ADD CONSTRAINT "PK_TestEntityA_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TestEntityB',
 'PK_TestEntityB_id',
 'ALTER TABLE ties_data."TestEntityB" ADD CONSTRAINT "PK_TestEntityB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_GROUPS_TESTENTITYB',
 'FK_TESTENTITYA_GROUPS_TESTENTITYB_aSide_TestEntityA',
 'ALTER TABLE ties_data."TESTENTITYA_GROUPS_TESTENTITYB" ADD CONSTRAINT "FK_TESTENTITYA_GROUPS_TESTENTITYB_aSide_TestEntityA" FOREIGN KEY ("aSide_TestEntityA") REFERENCES ties_data."TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_GROUPS_TESTENTITYB',
 'FK_TESTENTITYA_GROUPS_TESTENTITYB_bSide_TestEntityB',
 'ALTER TABLE ties_data."TESTENTITYA_GROUPS_TESTENTITYB" ADD CONSTRAINT "FK_TESTENTITYA_GROUPS_TESTENTITYB_bSide_TestEntityB" FOREIGN KEY ("bSide_TestEntityB") REFERENCES ties_data."TestEntityB" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_PROVIDES_TESTENTITYB',
 'FK_TESTENTITYA_PROVIDES_TESTENTITYB_aSide_TestEntityA',
 'ALTER TABLE ties_data."TESTENTITYA_PROVIDES_TESTENTITYB" ADD CONSTRAINT "FK_TESTENTITYA_PROVIDES_TESTENTITYB_aSide_TestEntityA" FOREIGN KEY ("aSide_TestEntityA") REFERENCES ties_data."TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TESTENTITYA_PROVIDES_TESTENTITYB',
 'FK_TESTENTITYA_PROVIDES_TESTENTITYB_bSide_TestEntityB',
 'ALTER TABLE ties_data."TESTENTITYA_PROVIDES_TESTENTITYB" ADD CONSTRAINT "FK_TESTENTITYA_PROVIDES_TESTENTITYB_bSide_TestEntityB" FOREIGN KEY ("bSide_TestEntityB") REFERENCES ties_data."TestEntityB" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TestEntityB',
 'FK_TestEntityB_REL_FK_used-by-testEntityA',
 'ALTER TABLE ties_data."TestEntityB" ADD CONSTRAINT "FK_TestEntityB_REL_FK_used-by-testEntityA" FOREIGN KEY ("REL_FK_used-by-testEntityA") REFERENCES ties_data."TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'TestEntityB',
 'UNIQUE_TestEntityB_REL_ID_TESTENTITYA_USES_TESTENTITYB',
 'ALTER TABLE ties_data."TestEntityB" ADD CONSTRAINT "UNIQUE_TestEntityB_REL_ID_TESTENTITYA_USES_TESTENTITYB" UNIQUE ("REL_ID_TESTENTITYA_USES_TESTENTITYB");'
);

ALTER TABLE ONLY ties_data."Site" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

CREATE TABLE IF NOT EXISTS ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" (
	"id"			VARCHAR(511),
	"fdn"			TEXT,
    "CD_sourceIds"			jsonb
);

ALTER TABLE ONLY ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';

SELECT ties_data.create_constraint_if_not_exists(
	'003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F',
 'PK_F568C5029499EE188A168886B2EF09C0D1FAAA9F',
 'ALTER TABLE ties_data."003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F" ADD CONSTRAINT "PK_F568C5029499EE188A168886B2EF09C0D1FAAA9F" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'1EF2A41C34A961CD8AE603E020B7B8B57345267F',
 'PK_19E2CBE3A8BBA12A7D9EC9923573BC0A65B1EC4A',
 'ALTER TABLE ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" ADD CONSTRAINT "PK_19E2CBE3A8BBA12A7D9EC9923573BC0A65B1EC4A" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'25978231183BE3B9ADD7DBE6C77F5E59696CDE5F',
 'PK_F52E445B46B712C0D9014D194AB039C205E69818',
 'ALTER TABLE ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ADD CONSTRAINT "PK_F52E445B46B712C0D9014D194AB039C205E69818" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'50AC08AB775076E74FC4891954F1D99D3D293ACC',
 'PK_CCB39BED50FEF60B1B1F86A7C938BE89B7D90D38',
 'ALTER TABLE ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" ADD CONSTRAINT "PK_CCB39BED50FEF60B1B1F86A7C938BE89B7D90D38" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'78682DB1FFA2533BA45F8E4FAA5596E1A98479FC',
 'PK_77881E9D6F659316F836050DDC6E26FA4DE425EE',
 'ALTER TABLE ties_data."78682DB1FFA2533BA45F8E4FAA5596E1A98479FC" ADD CONSTRAINT "PK_77881E9D6F659316F836050DDC6E26FA4DE425EE" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7D7AACEBB0E4E4732835BA4BFE708DDD3738962D',
 'PK_079D5D67E043B09F9C7CD4F6EA1DB12688D43F69',
 'ALTER TABLE ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" ADD CONSTRAINT "PK_079D5D67E043B09F9C7CD4F6EA1DB12688D43F69" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AC201B3A42917A9A983A1E3683B67C38C50630FC',
 'PK_5D1AC46C58E1FE44FB266F86CE79B3AEBE1D92B3',
 'ALTER TABLE ties_data."AC201B3A42917A9A983A1E3683B67C38C50630FC" ADD CONSTRAINT "PK_5D1AC46C58E1FE44FB266F86CE79B3AEBE1D92B3" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE',
 'PK_ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE_id',
 'ALTER TABLE ties_data."ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "PK_ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaCapability',
 'PK_AntennaCapability_id',
 'ALTER TABLE ties_data."AntennaCapability" ADD CONSTRAINT "PK_AntennaCapability_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaModule',
 'PK_AntennaModule_id',
 'ALTER TABLE ties_data."AntennaModule" ADD CONSTRAINT "PK_AntennaModule_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'PK_CloudNativeApplication_id',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "PK_CloudNativeApplication_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeSystem',
 'PK_CloudNativeSystem_id',
 'ALTER TABLE ties_data."CloudNativeSystem" ADD CONSTRAINT "PK_CloudNativeSystem_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudSite',
 'PK_CloudSite_id',
 'ALTER TABLE ties_data."CloudSite" ADD CONSTRAINT "PK_CloudSite_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ENodeBFunction',
 'PK_ENodeBFunction_id',
 'ALTER TABLE ties_data."ENodeBFunction" ADD CONSTRAINT "PK_ENodeBFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'EUtranCell',
 'PK_EUtranCell_id',
 'ALTER TABLE ties_data."EUtranCell" ADD CONSTRAINT "PK_EUtranCell_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'PK_GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "PK_GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFunction',
 'PK_GNBCUCPFunction_id',
 'ALTER TABLE ties_data."GNBCUCPFunction" ADD CONSTRAINT "PK_GNBCUCPFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'PK_GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "PK_GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFunction',
 'PK_GNBCUUPFunction_id',
 'ALTER TABLE ties_data."GNBCUUPFunction" ADD CONSTRAINT "PK_GNBCUUPFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'PK_GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "PK_GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFunction',
 'PK_GNBDUFunction_id',
 'ALTER TABLE ties_data."GNBDUFunction" ADD CONSTRAINT "PK_GNBDUFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'PK_LTESectorCarrier_id',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "PK_LTESectorCarrier_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ManagedElement',
 'PK_ManagedElement_id',
 'ALTER TABLE ties_data."ManagedElement" ADD CONSTRAINT "PK_ManagedElement_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellCU',
 'PK_NRCellCU_id',
 'ALTER TABLE ties_data."NRCellCU" ADD CONSTRAINT "PK_NRCellCU_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellDU',
 'PK_NRCellDU_id',
 'ALTER TABLE ties_data."NRCellDU" ADD CONSTRAINT "PK_NRCellDU_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'PK_NRSectorCarrier_id',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "PK_NRSectorCarrier_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'Namespace',
 'PK_Namespace_id',
 'ALTER TABLE ties_data."Namespace" ADD CONSTRAINT "PK_Namespace_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NodeCluster',
 'PK_NodeCluster_id',
 'ALTER TABLE ties_data."NodeCluster" ADD CONSTRAINT "PK_NodeCluster_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'PhysicalNetworkAppliance',
 'PK_PhysicalNetworkAppliance_id',
 'ALTER TABLE ties_data."PhysicalNetworkAppliance" ADD CONSTRAINT "PK_PhysicalNetworkAppliance_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'Sector',
 'PK_Sector_id',
 'ALTER TABLE ties_data."Sector" ADD CONSTRAINT "PK_Sector_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'Site',
 'PK_Site_id',
 'ALTER TABLE ties_data."Site" ADD CONSTRAINT "PK_Site_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F',
 'FK_54FE608944AC8EFFFBE7E55744B8BA52F6B29ABB',
 'ALTER TABLE ties_data."003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F" ADD CONSTRAINT "FK_54FE608944AC8EFFFBE7E55744B8BA52F6B29ABB" FOREIGN KEY ("REL_FK_C2F5EC33C0760F653CE7263A49C0B697FCA2D542") REFERENCES ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'1EF2A41C34A961CD8AE603E020B7B8B57345267F',
 'FK_9C091709D40D51DEE4DC87A44695F6EBA2E965DE',
 'ALTER TABLE ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" ADD CONSTRAINT "FK_9C091709D40D51DEE4DC87A44695F6EBA2E965DE" FOREIGN KEY ("REL_FK_26958E3A529C4C8B68A29FDA906F8CD290F66078") REFERENCES ties_data."003B7CAE0FA8C3C54BE1BAD8BB9A50985A2EA03F" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'1EF2A41C34A961CD8AE603E020B7B8B57345267F',
 'UNIQUE_9A721779BB5547778B9258ACD73261B9AABFF302',
 'ALTER TABLE ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" ADD CONSTRAINT "UNIQUE_9A721779BB5547778B9258ACD73261B9AABFF302" UNIQUE ("REL_ID_B7945BFD83380F3E12CF99F2B0F838F364027F92");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'25978231183BE3B9ADD7DBE6C77F5E59696CDE5F',
 'FK_899FCB466B0BBCC040E945A3E746F5DE53CCCB29',
 'ALTER TABLE ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ADD CONSTRAINT "FK_899FCB466B0BBCC040E945A3E746F5DE53CCCB29" FOREIGN KEY ("REL_FK_AB87B417CCD05C332DDD0C60F0C6AB41D38B05E5") REFERENCES ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'25978231183BE3B9ADD7DBE6C77F5E59696CDE5F',
 'UNIQUE_3DDA71C08F678AA7303FE0BD127CC27A80D1DDED',
 'ALTER TABLE ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ADD CONSTRAINT "UNIQUE_3DDA71C08F678AA7303FE0BD127CC27A80D1DDED" UNIQUE ("REL_ID_FC2F6A5A12917357B548C83F4B0C1AD58FA61413");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'25978231183BE3B9ADD7DBE6C77F5E59696CDE5F',
 'FK_E33FB71E6FAC69C92ADEEC55E63D401D21DF91AE',
 'ALTER TABLE ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ADD CONSTRAINT "FK_E33FB71E6FAC69C92ADEEC55E63D401D21DF91AE" FOREIGN KEY ("REL_FK_8C98B70070BBD11F90F192DDA3ECF6302390E956") REFERENCES ties_data."78682DB1FFA2533BA45F8E4FAA5596E1A98479FC" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'25978231183BE3B9ADD7DBE6C77F5E59696CDE5F',
 'UNIQUE_287E65679DC2108F55F43D62A4325F6DECF372E1',
 'ALTER TABLE ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" ADD CONSTRAINT "UNIQUE_287E65679DC2108F55F43D62A4325F6DECF372E1" UNIQUE ("REL_ID_AFBF10D23507AD3B6408947D2A9AF8465BA7B08C");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'50AC08AB775076E74FC4891954F1D99D3D293ACC',
 'FK_D43434F9F6FD1C14BE14A0EEDA4C9918B26E82F1',
 'ALTER TABLE ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" ADD CONSTRAINT "FK_D43434F9F6FD1C14BE14A0EEDA4C9918B26E82F1" FOREIGN KEY ("REL_FK_609963BFEE15FF824280FBE201313C3CDACDDDCE") REFERENCES ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'50AC08AB775076E74FC4891954F1D99D3D293ACC',
 'UNIQUE_4E6028C8AF5DB6D082B612C5CBB5B32A943C0AAD',
 'ALTER TABLE ties_data."50AC08AB775076E74FC4891954F1D99D3D293ACC" ADD CONSTRAINT "UNIQUE_4E6028C8AF5DB6D082B612C5CBB5B32A943C0AAD" UNIQUE ("REL_ID_040FC8B06B420BA5708AF4798102D1E65FB4DC61");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7D7AACEBB0E4E4732835BA4BFE708DDD3738962D',
 'FK_C5EB2FEB41FDD27A7CED04A3FD665B4BDEF994F5',
 'ALTER TABLE ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" ADD CONSTRAINT "FK_C5EB2FEB41FDD27A7CED04A3FD665B4BDEF994F5" FOREIGN KEY ("REL_FK_48B14FA5B787C6398AD1DE5EE670AD0D2A2CB36F") REFERENCES ties_data."1EF2A41C34A961CD8AE603E020B7B8B57345267F" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7D7AACEBB0E4E4732835BA4BFE708DDD3738962D',
 'UNIQUE_176E72F1225D7EEFC222D87B6EC4D66DD968BD13',
 'ALTER TABLE ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" ADD CONSTRAINT "UNIQUE_176E72F1225D7EEFC222D87B6EC4D66DD968BD13" UNIQUE ("REL_ID_BDE0B6C74D14AC109D29A08D80E92D4D0DCAEB0B");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AC201B3A42917A9A983A1E3683B67C38C50630FC',
 'FK_BFC9C18D6DBCD1FFC021B021CF31444EAA1FEDCA',
 'ALTER TABLE ties_data."AC201B3A42917A9A983A1E3683B67C38C50630FC" ADD CONSTRAINT "FK_BFC9C18D6DBCD1FFC021B021CF31444EAA1FEDCA" FOREIGN KEY ("aSide_B0FD0521695A211BFF76F413A31F28CBA32E57ED") REFERENCES ties_data."7D7AACEBB0E4E4732835BA4BFE708DDD3738962D" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AC201B3A42917A9A983A1E3683B67C38C50630FC',
 'FK_EADC754A352728E72F7320F69D802725C71EDE3E',
 'ALTER TABLE ties_data."AC201B3A42917A9A983A1E3683B67C38C50630FC" ADD CONSTRAINT "FK_EADC754A352728E72F7320F69D802725C71EDE3E" FOREIGN KEY ("bSide_84EF1134719BB6FCF33A94FF770311FC722BCF41") REFERENCES ties_data."25978231183BE3B9ADD7DBE6C77F5E59696CDE5F" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE',
 'FK_03713853A2B7ACDC198858CAFBFF355026FEA0B3',
 'ALTER TABLE ties_data."ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "FK_03713853A2B7ACDC198858CAFBFF355026FEA0B3" FOREIGN KEY ("aSide_AntennaCapability") REFERENCES ties_data."AntennaCapability" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE',
 'FK_5059CE8D2FEE5A1FAD9E06F4FAAFC148BAEA70E3',
 'ALTER TABLE ties_data."ANTENNACAPABILITY_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "FK_5059CE8D2FEE5A1FAD9E06F4FAAFC148BAEA70E3" FOREIGN KEY ("bSide_AntennaModule") REFERENCES ties_data."AntennaModule" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaCapability',
 'FK_AntennaCapability_REL_FK_used-by-lteSectorCarrier',
 'ALTER TABLE ties_data."AntennaCapability" ADD CONSTRAINT "FK_AntennaCapability_REL_FK_used-by-lteSectorCarrier" FOREIGN KEY ("REL_FK_used-by-lteSectorCarrier") REFERENCES ties_data."LTESectorCarrier" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaModule',
 'FK_AntennaModule_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."AntennaModule" ADD CONSTRAINT "FK_AntennaModule_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."Sector" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaModule',
 'UNIQUE_AntennaModule_REL_ID_SECTOR_GROUPS_ANTENNAMODULE',
 'ALTER TABLE ties_data."AntennaModule" ADD CONSTRAINT "UNIQUE_AntennaModule_REL_ID_SECTOR_GROUPS_ANTENNAMODULE" UNIQUE ("REL_ID_SECTOR_GROUPS_ANTENNAMODULE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaModule',
 'FK_AntennaModule_REL_FK_installed-at-site',
 'ALTER TABLE ties_data."AntennaModule" ADD CONSTRAINT "FK_AntennaModule_REL_FK_installed-at-site" FOREIGN KEY ("REL_FK_installed-at-site") REFERENCES ties_data."Site" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'AntennaModule',
 'UNIQUE_AntennaModule_REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE',
 'ALTER TABLE ties_data."AntennaModule" ADD CONSTRAINT "UNIQUE_AntennaModule_REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE" UNIQUE ("REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'FK_CloudNativeApplication_REL_FK_realised-managedElement',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_realised-managedElement" FOREIGN KEY ("REL_FK_realised-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'UNIQUE_DAB3C12479849DA6C222B812C2A8CD1535D0C186',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "UNIQUE_DAB3C12479849DA6C222B812C2A8CD1535D0C186" UNIQUE ("REL_ID_MANAGEDELEMENT_REALISED_BY_CLOUDNATIVEAPPLICATION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'FK_CloudNativeApplication_REL_FK_comprised-by-cloudNativeSystem',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_comprised-by-cloudNativeSystem" FOREIGN KEY ("REL_FK_comprised-by-cloudNativeSystem") REFERENCES ties_data."CloudNativeSystem" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'UNIQUE_F2774BC0806E925ADA0B1CAA50B5A41DFB7BF79A',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "UNIQUE_F2774BC0806E925ADA0B1CAA50B5A41DFB7BF79A" UNIQUE ("REL_ID_CLOUDNATIVESYSTEM_COMPRISES_CLOUDNATIVEAPPLICATION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'FK_CloudNativeApplication_REL_FK_deployed-on-namespace',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_deployed-on-namespace" FOREIGN KEY ("REL_FK_deployed-on-namespace") REFERENCES ties_data."Namespace" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeApplication',
 'UNIQUE_1A317D31DA93B0CF9A9F8A04077B0F60ABCFF49C',
 'ALTER TABLE ties_data."CloudNativeApplication" ADD CONSTRAINT "UNIQUE_1A317D31DA93B0CF9A9F8A04077B0F60ABCFF49C" UNIQUE ("REL_ID_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'CloudNativeSystem',
 'FK_CloudNativeSystem_REL_FK_deployed-managedElement',
 'ALTER TABLE ties_data."CloudNativeSystem" ADD CONSTRAINT "FK_CloudNativeSystem_REL_FK_deployed-managedElement" FOREIGN KEY ("REL_FK_deployed-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ENodeBFunction',
 'FK_ENodeBFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."ENodeBFunction" ADD CONSTRAINT "FK_ENodeBFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ENodeBFunction',
 'UNIQUE_F33037EE8037D0606D15FFB45EE8A27FD6DE30EE',
 'ALTER TABLE ties_data."ENodeBFunction" ADD CONSTRAINT "UNIQUE_F33037EE8037D0606D15FFB45EE8A27FD6DE30EE" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ENodeBFunction',
 'FK_ENodeBFunction_REL_FK_realised-by-physicalNetworkAppliance',
 'ALTER TABLE ties_data."ENodeBFunction" ADD CONSTRAINT "FK_ENodeBFunction_REL_FK_realised-by-physicalNetworkAppliance" FOREIGN KEY ("REL_FK_realised-by-physicalNetworkAppliance") REFERENCES ties_data."PhysicalNetworkAppliance" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ENodeBFunction',
 'UNIQUE_6964DA7D7CC1F79A3DB8B43E5F77E42DF8DFBF73',
 'ALTER TABLE ties_data."ENodeBFunction" ADD CONSTRAINT "UNIQUE_6964DA7D7CC1F79A3DB8B43E5F77E42DF8DFBF73" UNIQUE ("REL_ID_ENODEBFUNCTION_REALISED_BY_PHYSICALNETWORKAPPLIANCE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'EUtranCell',
 'FK_EUtranCell_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."EUtranCell" ADD CONSTRAINT "FK_EUtranCell_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."Sector" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'EUtranCell',
 'UNIQUE_EUtranCell_REL_ID_SECTOR_GROUPS_EUTRANCELL',
 'ALTER TABLE ties_data."EUtranCell" ADD CONSTRAINT "UNIQUE_EUtranCell_REL_ID_SECTOR_GROUPS_EUTRANCELL" UNIQUE ("REL_ID_SECTOR_GROUPS_EUTRANCELL");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'EUtranCell',
 'FK_EUtranCell_REL_FK_provided-by-enodebFunction',
 'ALTER TABLE ties_data."EUtranCell" ADD CONSTRAINT "FK_EUtranCell_REL_FK_provided-by-enodebFunction" FOREIGN KEY ("REL_FK_provided-by-enodebFunction") REFERENCES ties_data."ENodeBFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'EUtranCell',
 'UNIQUE_EUtranCell_REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL',
 'ALTER TABLE ties_data."EUtranCell" ADD CONSTRAINT "UNIQUE_EUtranCell_REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL" UNIQUE ("REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_B2DDDC542E95DD31826EECEBBF67FD01DAF48833',
 'ALTER TABLE ties_data."GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_B2DDDC542E95DD31826EECEBBF67FD01DAF48833" FOREIGN KEY ("aSide_GNBCUCPFunction") REFERENCES ties_data."GNBCUCPFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_95C3AD1FCFBD310B9947B9B622CA8E0FC2135DC5',
 'ALTER TABLE ties_data."GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_95C3AD1FCFBD310B9947B9B622CA8E0FC2135DC5" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."CloudNativeApplication" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFunction',
 'FK_GNBCUCPFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."GNBCUCPFunction" ADD CONSTRAINT "FK_GNBCUCPFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUCPFunction',
 'UNIQUE_249F73FF1F4316A56DEF4424FA43C2064FFBE4DD',
 'ALTER TABLE ties_data."GNBCUCPFunction" ADD CONSTRAINT "UNIQUE_249F73FF1F4316A56DEF4424FA43C2064FFBE4DD" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_F3346189A1BB0DA705219A4136349DF50AE8AA33',
 'ALTER TABLE ties_data."GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_F3346189A1BB0DA705219A4136349DF50AE8AA33" FOREIGN KEY ("aSide_GNBCUUPFunction") REFERENCES ties_data."GNBCUUPFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_36215EA9FC5F31CC0F131E526A84A54CB006C66B',
 'ALTER TABLE ties_data."GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_36215EA9FC5F31CC0F131E526A84A54CB006C66B" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."CloudNativeApplication" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFunction',
 'FK_GNBCUUPFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."GNBCUUPFunction" ADD CONSTRAINT "FK_GNBCUUPFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBCUUPFunction',
 'UNIQUE_BDB349CDF0C4055902881ECCB71F460AE1DD323E',
 'ALTER TABLE ties_data."GNBCUUPFunction" ADD CONSTRAINT "UNIQUE_BDB349CDF0C4055902881ECCB71F460AE1DD323E" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_69C6800CC81731E475893CC85582971C7530C98E',
 'ALTER TABLE ties_data."GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_69C6800CC81731E475893CC85582971C7530C98E" FOREIGN KEY ("aSide_GNBDUFunction") REFERENCES ties_data."GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION',
 'FK_CA6721EE0944CBBB8E071CEA630162ABD7DFF2DA',
 'ALTER TABLE ties_data."GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION" ADD CONSTRAINT "FK_CA6721EE0944CBBB8E071CEA630162ABD7DFF2DA" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."CloudNativeApplication" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFunction',
 'FK_GNBDUFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."GNBDUFunction" ADD CONSTRAINT "FK_GNBDUFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'GNBDUFunction',
 'UNIQUE_08DFEFAF56EDDE43CBDC336F459D28C6518D3E1D',
 'ALTER TABLE ties_data."GNBDUFunction" ADD CONSTRAINT "UNIQUE_08DFEFAF56EDDE43CBDC336F459D28C6518D3E1D" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'FK_LTESectorCarrier_REL_FK_provided-by-enodebFunction',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_provided-by-enodebFunction" FOREIGN KEY ("REL_FK_provided-by-enodebFunction") REFERENCES ties_data."ENodeBFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'UNIQUE_B9770D6C26DDA0173DB9690F6E3B42C111AF26E9',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "UNIQUE_B9770D6C26DDA0173DB9690F6E3B42C111AF26E9" UNIQUE ("REL_ID_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'FK_LTESectorCarrier_REL_FK_used-antennaCapability',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_used-antennaCapability" FOREIGN KEY ("REL_FK_used-antennaCapability") REFERENCES ties_data."AntennaCapability" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'UNIQUE_5D5FEB6B4B09D5D42A589753C684994CD0B96E88',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "UNIQUE_5D5FEB6B4B09D5D42A589753C684994CD0B96E88" UNIQUE ("REL_ID_LTESECTORCARRIER_USES_ANTENNACAPABILITY");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'FK_LTESectorCarrier_REL_FK_used-by-euTranCell',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_used-by-euTranCell" FOREIGN KEY ("REL_FK_used-by-euTranCell") REFERENCES ties_data."EUtranCell" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'LTESectorCarrier',
 'UNIQUE_LTESectorCarrier_REL_ID_EUTRANCELL_USES_LTESECTORCARRIER',
 'ALTER TABLE ties_data."LTESectorCarrier" ADD CONSTRAINT "UNIQUE_LTESectorCarrier_REL_ID_EUTRANCELL_USES_LTESECTORCARRIER" UNIQUE ("REL_ID_EUTRANCELL_USES_LTESECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ManagedElement',
 'FK_ManagedElement_REL_FK_deployed-as-cloudNativeSystem',
 'ALTER TABLE ties_data."ManagedElement" ADD CONSTRAINT "FK_ManagedElement_REL_FK_deployed-as-cloudNativeSystem" FOREIGN KEY ("REL_FK_deployed-as-cloudNativeSystem") REFERENCES ties_data."CloudNativeSystem" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ManagedElement',
 'UNIQUE_ADD7C124AEF822CB0293FC75E39449DC1AD097E5',
 'ALTER TABLE ties_data."ManagedElement" ADD CONSTRAINT "UNIQUE_ADD7C124AEF822CB0293FC75E39449DC1AD097E5" UNIQUE ("REL_ID_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellCU',
 'FK_NRCellCU_REL_FK_provided-by-gnbcucpFunction',
 'ALTER TABLE ties_data."NRCellCU" ADD CONSTRAINT "FK_NRCellCU_REL_FK_provided-by-gnbcucpFunction" FOREIGN KEY ("REL_FK_provided-by-gnbcucpFunction") REFERENCES ties_data."GNBCUCPFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellCU',
 'UNIQUE_NRCellCU_REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU',
 'ALTER TABLE ties_data."NRCellCU" ADD CONSTRAINT "UNIQUE_NRCellCU_REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" UNIQUE ("REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellDU',
 'FK_NRCellDU_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."NRCellDU" ADD CONSTRAINT "FK_NRCellDU_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."Sector" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellDU',
 'UNIQUE_NRCellDU_REL_ID_SECTOR_GROUPS_NRCELLDU',
 'ALTER TABLE ties_data."NRCellDU" ADD CONSTRAINT "UNIQUE_NRCellDU_REL_ID_SECTOR_GROUPS_NRCELLDU" UNIQUE ("REL_ID_SECTOR_GROUPS_NRCELLDU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellDU',
 'FK_NRCellDU_REL_FK_provided-by-gnbduFunction',
 'ALTER TABLE ties_data."NRCellDU" ADD CONSTRAINT "FK_NRCellDU_REL_FK_provided-by-gnbduFunction" FOREIGN KEY ("REL_FK_provided-by-gnbduFunction") REFERENCES ties_data."GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRCellDU',
 'UNIQUE_NRCellDU_REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU',
 'ALTER TABLE ties_data."NRCellDU" ADD CONSTRAINT "UNIQUE_NRCellDU_REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU" UNIQUE ("REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'FK_NRSectorCarrier_REL_FK_used-by-nrCellDu',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_used-by-nrCellDu" FOREIGN KEY ("REL_FK_used-by-nrCellDu") REFERENCES ties_data."NRCellDU" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'UNIQUE_NRSectorCarrier_REL_ID_NRCELLDU_USES_NRSECTORCARRIER',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "UNIQUE_NRSectorCarrier_REL_ID_NRCELLDU_USES_NRSECTORCARRIER" UNIQUE ("REL_ID_NRCELLDU_USES_NRSECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'FK_NRSectorCarrier_REL_FK_provided-by-gnbduFunction',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_provided-by-gnbduFunction" FOREIGN KEY ("REL_FK_provided-by-gnbduFunction") REFERENCES ties_data."GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'UNIQUE_872BE05F1989443F2595D99A77BC03733B2D1E2F',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "UNIQUE_872BE05F1989443F2595D99A77BC03733B2D1E2F" UNIQUE ("REL_ID_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'FK_NRSectorCarrier_REL_FK_used-antennaCapability',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_used-antennaCapability" FOREIGN KEY ("REL_FK_used-antennaCapability") REFERENCES ties_data."AntennaCapability" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NRSectorCarrier',
 'UNIQUE_EDF7D5C78EF6505848B1679B714D7831F5863991',
 'ALTER TABLE ties_data."NRSectorCarrier" ADD CONSTRAINT "UNIQUE_EDF7D5C78EF6505848B1679B714D7831F5863991" UNIQUE ("REL_ID_NRSECTORCARRIER_USES_ANTENNACAPABILITY");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'Namespace',
 'FK_Namespace_REL_FK_deployed-on-nodeCluster',
 'ALTER TABLE ties_data."Namespace" ADD CONSTRAINT "FK_Namespace_REL_FK_deployed-on-nodeCluster" FOREIGN KEY ("REL_FK_deployed-on-nodeCluster") REFERENCES ties_data."NodeCluster" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'Namespace',
 'UNIQUE_Namespace_REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER',
 'ALTER TABLE ties_data."Namespace" ADD CONSTRAINT "UNIQUE_Namespace_REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER" UNIQUE ("REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NodeCluster',
 'FK_NodeCluster_REL_FK_located-at-cloudSite',
 'ALTER TABLE ties_data."NodeCluster" ADD CONSTRAINT "FK_NodeCluster_REL_FK_located-at-cloudSite" FOREIGN KEY ("REL_FK_located-at-cloudSite") REFERENCES ties_data."CloudSite" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'NodeCluster',
 'UNIQUE_NodeCluster_REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE',
 'ALTER TABLE ties_data."NodeCluster" ADD CONSTRAINT "UNIQUE_NodeCluster_REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE" UNIQUE ("REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'PhysicalNetworkAppliance',
 'FK_PhysicalNetworkAppliance_REL_FK_installed-at-site',
 'ALTER TABLE ties_data."PhysicalNetworkAppliance" ADD CONSTRAINT "FK_PhysicalNetworkAppliance_REL_FK_installed-at-site" FOREIGN KEY ("REL_FK_installed-at-site") REFERENCES ties_data."Site" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'PhysicalNetworkAppliance',
 'UNIQUE_A9110A77514C472452AC80053A8010FBAF481AD0',
 'ALTER TABLE ties_data."PhysicalNetworkAppliance" ADD CONSTRAINT "UNIQUE_A9110A77514C472452AC80053A8010FBAF481AD0" UNIQUE ("REL_ID_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNAMODULE_REALISED_BY_ANTENNAMODULE',
 'PK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_id',
 'ALTER TABLE ties_data."ANTENNAMODULE_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "PK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNAMODULE_REALISED_BY_ANTENNAMODULE',
 'FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_aSide_AntennaModule',
 'ALTER TABLE ties_data."ANTENNAMODULE_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_aSide_AntennaModule" FOREIGN KEY ("aSide_AntennaModule") REFERENCES ties_data."AntennaModule" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ANTENNAMODULE_REALISED_BY_ANTENNAMODULE',
 'FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_bSide_AntennaModule',
 'ALTER TABLE ties_data."ANTENNAMODULE_REALISED_BY_ANTENNAMODULE" ADD CONSTRAINT "FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_bSide_AntennaModule" FOREIGN KEY ("bSide_AntennaModule") REFERENCES ties_data."AntennaModule" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'B69D3E92CA22CE61B921AE61BD3CF031791CF714',
 'PK_2673E8FB17E57FD56D5E897DA13412B9165B90AA',
 'ALTER TABLE ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" ADD CONSTRAINT "PK_2673E8FB17E57FD56D5E897DA13412B9165B90AA" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6',
 'PK_E3722EAF721B41FACDCF065D2017267CE2C90BED',
 'ALTER TABLE ties_data."B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6" ADD CONSTRAINT "PK_E3722EAF721B41FACDCF065D2017267CE2C90BED" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6',
 'FK_00AE9B9921E38ACFEE934695787FA8794817A6ED',
 'ALTER TABLE ties_data."B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6" ADD CONSTRAINT "FK_00AE9B9921E38ACFEE934695787FA8794817A6ED" FOREIGN KEY ("aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C") REFERENCES ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6',
 'FK_68EED3C83D2C93559F7A61E7D05B4363CDF1DB8F',
 'ALTER TABLE ties_data."B9B76FD20FF23B2A41C82CB5EDF6FA25B6AC2BC6" ADD CONSTRAINT "FK_68EED3C83D2C93559F7A61E7D05B4363CDF1DB8F" FOREIGN KEY ("bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E") REFERENCES ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'C35AE10CFF62DEDC5E3FC3C40E47373B10800818',
 'PK_F03D1DD176CD75707BD6217EF652705007C0F272',
 'ALTER TABLE ties_data."C35AE10CFF62DEDC5E3FC3C40E47373B10800818" ADD CONSTRAINT "PK_F03D1DD176CD75707BD6217EF652705007C0F272" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'C35AE10CFF62DEDC5E3FC3C40E47373B10800818',
 'FK_E19DA712FB443E0212578638DF62281CFD6BFA7A',
 'ALTER TABLE ties_data."C35AE10CFF62DEDC5E3FC3C40E47373B10800818" ADD CONSTRAINT "FK_E19DA712FB443E0212578638DF62281CFD6BFA7A" FOREIGN KEY ("aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C") REFERENCES ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'C35AE10CFF62DEDC5E3FC3C40E47373B10800818',
 'FK_7772B14325D2340707AF687BF0F70F32914F935D',
 'ALTER TABLE ties_data."C35AE10CFF62DEDC5E3FC3C40E47373B10800818" ADD CONSTRAINT "FK_7772B14325D2340707AF687BF0F70F32914F935D" FOREIGN KEY ("bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E") REFERENCES ties_data."B69D3E92CA22CE61B921AE61BD3CF031791CF714" (id) ON DELETE CASCADE;'
);
